==> kubernetes-model-kustomize-6.6.0-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/SortOptionsFluent.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface SortOptionsFluent<A extends SortOptionsFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildLegacySortOptions instead.
   * @return The buildable object.
   */
  @Deprecated
  public LegacySortOptions getLegacySortOptions();
  public LegacySortOptions buildLegacySortOptions();
  public A withLegacySortOptions(LegacySortOptions legacySortOptions);
  public Boolean hasLegacySortOptions();
  public SortOptionsFluent.LegacySortOptionsNested<A> withNewLegacySortOptions();
  public SortOptionsFluent.LegacySortOptionsNested<A> withNewLegacySortOptionsLike(LegacySortOptions item);
  public SortOptionsFluent.LegacySortOptionsNested<A> editLegacySortOptions();
  public SortOptionsFluent.LegacySortOptionsNested<A> editOrNewLegacySortOptions();
  public SortOptionsFluent.LegacySortOptionsNested<A> editOrNewLegacySortOptionsLike(LegacySortOptions item);
  public String getOrder();
  public A withOrder(String order);
  public Boolean hasOrder();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface LegacySortOptionsNested<N> extends Nested<N>,LegacySortOptionsFluent<SortOptionsFluent.LegacySortOptionsNested<N>>{
    public N and();
    public N endLegacySortOptions();
    
  }
  
}

==> kubernetes-model-kustomize-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/SortOptionsFluent.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface SortOptionsFluent<A extends SortOptionsFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildLegacySortOptions instead.
   * @return The buildable object.
   */
  @Deprecated
  public LegacySortOptions getLegacySortOptions();
  public LegacySortOptions buildLegacySortOptions();
  public A withLegacySortOptions(LegacySortOptions legacySortOptions);
  public Boolean hasLegacySortOptions();
  public SortOptionsFluent.LegacySortOptionsNested<A> withNewLegacySortOptions();
  public SortOptionsFluent.LegacySortOptionsNested<A> withNewLegacySortOptionsLike(LegacySortOptions item);
  public SortOptionsFluent.LegacySortOptionsNested<A> editLegacySortOptions();
  public SortOptionsFluent.LegacySortOptionsNested<A> editOrNewLegacySortOptions();
  public SortOptionsFluent.LegacySortOptionsNested<A> editOrNewLegacySortOptionsLike(LegacySortOptions item);
  public String getOrder();
  public A withOrder(String order);
  public Boolean hasOrder();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface LegacySortOptionsNested<N> extends Nested<N>,LegacySortOptionsFluent<SortOptionsFluent.LegacySortOptionsNested<N>>{
    public N and();
    public N endLegacySortOptions();
    
  }
  
}
